@@ -49,12 +49,13 @@ from polly.tracking import Track
 
 class OmixAtlas:
     """
-    OmixAtlas class enables users to interact with functional properties of the omixatlas such as \
-    create and update an Omixatlas, get summary of it's contents, add, insert, update the schema, \
-    add, update or delete datasets, query metadata, download data, save data to workspace etc.\
+    OmixAtlas class enables users to interact with functional properties of the omixatlas such as
+    create and update an Omixatlas, get summary of it's contents, add, insert, update the schema,
+    add, update or delete datasets, query metadata, download data, save data to workspace etc.
 
     Args:
         token (str): token copy from polly.
+
     Usage:
         from polly.OmixAtlas import OmixAtlas
 
@@ -78,21 +79,25 @@ class OmixAtlas:
             f"https://api.datalake.discover.{self.session.env}.elucidata.io/elastic/v2"
         )
         self.resource_url = f"{self.base_url}/v1/omixatlases"
+        self.resource_url_search = (
+            f"https://apis.{self.session.env}.elucidata.io/mithoo/_search"
+        )
 
     @Track.track_decorator
     def get_all_omixatlas(
         self, query_api_version="v2", count_by_source=True, count_by_data_type=True
     ):
         """
-        This function will return the summary of all the Omixatlas on Polly which the user has access to.\
+        This function will return the summary of all the Omixatlas on Polly which the user has access to.
         Please use this function with default values for the paramters.
+
         Args:
             query_api_version (str): query api version
             count_by_source (bool): count by source
             count_by_data_type (bool): count by data type
 
         Returns:
-            It will return a list of JSON objects. (See Examples)
+            list: It will return a list of JSON objects. (See Examples)
 
         Raises:
             wrongParamException: invalid parameter passed
@@ -137,15 +142,17 @@ class OmixAtlas:
         count_by_data_type=True,
     ):
         """
-        This function will return you a object that contain summary of a given Omixatlas.\
+        This function will return you a object that contain summary of a given Omixatlas.
         Please use the function with the default values for optional parameters.
+
         Args:
             repo_key (str): repo_id or repo_name.
             query_api_version (str, optional): query api version
             count_by_source (bool, optional): count by source
             count_by_data_type (bool, optional): count by data_type
+
         Returns:
-            It will return a JSON object. (see examples)
+            object: It will return a JSON object. (see examples)
 
         Raises:
             wrongParamException: invalid paramter passed.
@@ -261,11 +268,11 @@ class OmixAtlas:
     ) -> pd.DataFrame:
         """
         This function will return a dataframe containing the SQL response.
-        In cases of data intensive queries, the data returned can be very large to process and it might lead to kernel failure\
+        In cases of data intensive queries, the data returned can be very large to process and it might lead to kernel failure
         , where in the runtime memory is exhausted and the process haults.
-        In order to access the data, there are two options in this case, either increase the kernel memory, \
+        In order to access the data, there are two options in this case, either increase the kernel memory,
         or use the function query_metadata_iterator() that returns an iterator.
-        The function usage can be looked up in the documentation mentioned here under the \
+        The function usage can be looked up in the documentation mentioned here under the
         Polly Python section - "https://docs.elucidata.io/index.html".
 
         Args:
@@ -612,6 +619,7 @@ class OmixAtlas:
         Function to get the Schema of all the tables in an OmixAtlas.
         User need to have Data Admin at the resource level to get the schema of an OmixAtlas.
         Please contact polly@support.com if you get Access Denied error message.
+
         Args:
             repo_key (str): repo_id OR repo_name. This is a mandatory field.
             schema_level (list, optional): Table name for which users want to get the schema. \
@@ -625,6 +633,7 @@ class OmixAtlas:
             For users, who want to perform schema management, they should get the output in "dict" format. \
             Dataframe format doesn't give the complete schema, it only shows the information \
             which aids users for writing queryies. Default value is "dataframe".
+
         Raises:
             paramException: When Function Parameter passed are not in the right format.
             RequestException: There is some issue in fetching the Schema.
@@ -679,13 +688,15 @@ class OmixAtlas:
     def insert_schema(self, repo_key, body: dict):
         """
         This function is used to insert the Schema in a newly created OmixAtlas.
-        In order to insert schema the user must be a Data Admin at the resource level.
+        In order to insert schema the user must be a Data Admin at the resource level.<br>
         Please contact polly@support.com if you get Access Denied error message.
+
         Args:
             repo_key (str/int, Optional): repo_id OR repo_name of the OmixAtlas. Users can  \
             get this by running `get_all_omixatlas` function. If not passed, taken from payload.
             body (dict):  The payload should be a JSON file for a specific table as per the structure defined for \
             schema.
+
         Raises:
             RequestException: Some Issue in Inserting the Schema for the OmixAtlas.
         """
@@ -702,21 +713,22 @@ class OmixAtlas:
         If the user wants to edit a field or its attribute in existing schema or if they want to
         add or delete new fields or if they want add a new source or datatype then they should use
         update schema function.\
-        Using update_schema, users can:\
-            ADD new source or datatypes in the schema\
-            ADD a new field to a source+data_type combination\
-            UPDATE attributes of an existing field\
-            However, using update_schema, users can't perform DELETE operations on any field, source or datatype.\
+        Using update_schema, users can:<br>
+            1. ADD new source or datatypes in the schema<br>
+            2. ADD a new field to a source+data_type combination<br>
+            3. UPDATE attributes of an existing field<br>
+            However, using update_schema, users can't perform DELETE operations on any field, source or datatype.<br><br>
         A message will be displayed on the status of the operation.\
-        In order to update schema the user must be a Data Admin at the resource level.\
+        In order to update schema the user must be a Data Admin at the resource level.<br>
         Please contact polly@support.com if you get Access Denied error message.\
-        For more information, see
-        https://docs.elucidata.io/polly-python/OmixAtlas/Schema Management.html#change-schema-in-an-existing-atlas
+        For more information, (see Examples)
+
         Args:
             repo_key (str/int, Optional): repo_id OR repo_name of the OmixAtlas. Users can  \
             get this by running get_all_omixatlas function. If not passed, taken from payload.
             body (dict): The payload should be a JSON file for a specific table as per the structure defined for \
             schema.
+
         Raises:
             RequestException: Some Issue in Updating the Schema for the OmixAtlas.
             paramException: Parameter Functions are not passed correctly.
@@ -734,14 +746,15 @@ class OmixAtlas:
         A message will be displayed on the status of the operation.\
         Completely REPLACE the existing schema with the one provided, so it can do all the \
         ops (including deletion of fields if they are no longer present in the new incoming schema).\
-        In order to replace schema the user must be a Data Admin at the resource level.\
+        In order to replace schema the user must be a Data Admin at the resource level.<br>
         Please contact polly@support.com if you get Access Denied error message.\
-        For more information, see
-        https://docs.elucidata.io/polly-python/OmixAtlas/Schema Management.html#change-schema-in-an-existing-atlas
+        For more information, (see Examples)
+
         Args:
             repo_key (str/int, optional): repo_id OR repo_name of the OmixAtlas. Users can  \
             get this by running get_all_omixatlas function. If not passed, taken from payload.
             body (dict): The payload should be a JSON file for a specific table as per the structure defined for schema.
+
         Raises:
             RequestException: Some Issue in Replacing the Schema for the OmixAtlas.
             paramException: Parameter Functions are not passed correctly.
@@ -763,11 +776,13 @@ class OmixAtlas:
         The dataset_id can be obtained by querying the metadata at the dataset level using query_metadata().
 
         This data can be parsed into a data frame for better accessibility using the code under the examples section.
+
         Args:
               repo_key (str): repo_id OR repo_name. This is a mandatory field.
               payload (dict): The payload is a JSON file which should be as per the structure defined for schema.
               Only data-admin will have the authentication to update the schema.
               internal_call (bool): True if being called internally by other functions. Default is False
+
         Raises:
               apiErrorException: Params are either empty or its datatype is not correct or see detail.
         """
@@ -795,11 +810,13 @@ class OmixAtlas:
     ) -> json:
         """
         Function to download a dataset from OmixAtlas and save it to Workspaces.
+
         Args:
              repo_id (str): repo_id of the Omixatlas
              dataset_id (str): dataset id that needs to be saved
              workspace_id (int): workspace id in which the dataset needs to be saved
              workspace_path (str): path where the workspace resides
+
         Returns:
              json: Info about workspace where data is saved and of which Omixatlas
         """
@@ -905,23 +922,26 @@ class OmixAtlas:
         controls={},
     ) -> pd.DataFrame:
         """
-        This function is used to create a new omixatlas. \
-        The arguments category, data_type and org_id can only be set during creation of Omixatlas and cannot be \
+        This function is used to create a new omixatlas.
+        The arguments category, data_type and org_id can only be set during creation of Omixatlas and cannot be
         updated afterwards.
+
         Args:
             display_name (str): Display name of the omixatlas as shown on the GUI.
             description (str): description of the omixatlas.
             repo_name (str, optional): repo_name which is used to create index in database.
             image_url (str, optional): URL of the image which should be kept as the icon for omixatlas.
             components (list, optional): Optional Parameter.
-            category (str, optional): Optional parameter(public/private/diy_poa).Immutable argument. \
+            category (str, optional): Optional parameter(public/private/diy_poa).Immutable argument.
             By default it is private.
-            data_type (str, optional): Optional Parameter(single_cell/rna_seq).Immutable argument. \
+            data_type (str, optional): Optional Parameter(single_cell/rna_seq).Immutable argument.
             By default it is None. If category is `public` or `diy_poa` then `data_type` is mandatory.
-            org_id (str, optional): Optional Parameter. Org Id is mandatory to be passed when category \
+            org_id (str, optional): Optional Parameter. Org Id is mandatory to be passed when category
             of omixatlas is `diy_poa`. Org Id can be found on admin panel.
+
         Returns:
             Dataframe after creation of omixatlas.
+
         Raises:
             ValueError: Repository creation response is in Incorrect format.
         """
@@ -993,6 +1013,7 @@ class OmixAtlas:
     ) -> pd.DataFrame:
         """
         This function is used to update an omixatlas.
+
         Args:
              repo_key (str/int): repo_name/repo_id for that Omixatlas
              display_name (str, optional): Display name of the omixatlas as shown on the GUI.
@@ -1121,6 +1142,7 @@ class OmixAtlas:
         ingestion log will be shown in the data ingestion monitoring dashboard.
         In order to add datasets into Omixatlas the user must be a Data Contributor at the resource level.
         Please contact polly@support.com if you get Access Denied error message.
+
         Args:
             repo_id (int/str): repo_id for that Omixatlas
             source_folder_path (dict): source folder paths from data and metadata files are fetched.In this \
@@ -1132,9 +1154,11 @@ class OmixAtlas:
             validation (bool, optional): Optional parameter(True/False) Users was to activate validation. By Default False. \
             Means validation not active by default. Validation needs to be activated only when \
             validated files are being ingested.
+
         Raises:
             paramError: If Params are not passed in the desired format or value not valid.
             RequestException: If there is issue in data ingestion.
+
         Returns:
             pd.DataFrame: DataFrame showing Upload Status of Files
         """
@@ -1162,6 +1186,7 @@ class OmixAtlas:
         ingestion log will be shown in the data ingestion monitoring dashboard.
         In order to update datasets the user must be a Data Contributor at the resource level.
         Please contact polly@support.com if you get Access Denied error message.
+
         Args:
             repo_id (int/str): repo_id for that Omixatlas
             source_folder_path (dict): source folder paths from data and metadata files are fetched.In this \
@@ -1176,9 +1201,11 @@ class OmixAtlas:
             validation(bool, optional): Optional parameter(True/False) Users was to activate validation. By Default False. \
             Means validation not active by default. Validation needs to be activated only when \
             validated files are being ingested.
+
         Raises:
             paramError: If Params are not passed in the desired format or value not valid.
             RequestException: If there is issue in data ingestion.
+
         Returns:
             pd.DataFrame: DataFrame showing Upload Status of Files
         """
@@ -1242,6 +1269,7 @@ class OmixAtlas:
         This function is used to fetch the template of dataset level metadata in a given OmixAtlas.
         In order to ingest the dataset level metadata appropriately in the OmixAtlas, the user needs
         to ensure the metadata json file contains the keys as per the dataset level schema.
+
         Args:
             repo_id (str/int): repo_name/repo_id for that Omixatlas
             source (all, optional): Source/Sources present in the schema. Default value is "all"
@@ -1253,9 +1281,6 @@ class OmixAtlas:
         Raises:
             invalidApiResponseException: attribute/key error
 
-        Returns:
-            dictionary with the dataset level metadata
-
         """
         # for dataset level metadata index is files
         schema_type = "files"
@@ -1547,7 +1572,7 @@ class OmixAtlas:
             folder_path (str): local folder path where the files need to be downloaded
 
         Returns:
-            Downloads the datasets in the passed folder path
+            Download: Downloads the datasets in the passed folder path
         """
         try:
             report_obj = Reporting()
@@ -1589,6 +1614,7 @@ class OmixAtlas:
         This function is used to download the dataset level metadata into a json file.
         The key present in the json file can be controlled using the `metadata_key` argument of the function.
         Users should use `original_name` for data ingestion.
+
         Args:
             repo_key (str): repo_name/repo_id of the repository where dataset belongs to.
             dataset_id (str): dataset_id of the dataset for which metadata should be downloaded.
@@ -1598,6 +1624,7 @@ class OmixAtlas:
             For ingestion related use-cases, users should use `original_name` and for other purposes
             `field_name` should be preferred.
             The default value is `field_name`.
+
         Raises:
             InvalidParameterException: Invalid parameter passed
             InvalidPathException: Invalid file path passed
@@ -1664,12 +1691,9 @@ class OmixAtlas:
         Arguments:
             repo_key (int/str): repo_id OR repo_name. This is a mandatory field.
             dataset_ids (list): list of dataset_ids from the repo passed that users want to download data of
-            folder_path (str, optional): folder path where the datasets will be downloaded to. \
+            folder_path (str, optional): folder path where the datasets will be downloaded to.
             Default is the current working directory.
 
-        Returns:
-            None
-
         Raises:
             InvalidParameterException : invalid or missing parameter
             paramException : invalid or missing folder_path provided
@@ -1750,13 +1774,15 @@ class OmixAtlas:
     ) -> pd.DataFrame:
         """
         This function is used to get the sample level metadata as a dataframe.
+
         Args:
             repo_key(str): repo_name/repo_id of the repository.
             dataset_id(str): dataset_id of the dataset.
             table_name(str): table name for the desired metadata, 'samples','samples_singlecell' supported for now.
+
         Raises:
-              paramException:
-              RequestFailureException:
+              paramException: invalid or missing parameter provided
+              RequestFailureException: Request failed
         """
         omix_hlpr.check_params_for_get_metadata(repo_key, dataset_id, table_name)
         repo_key = omix_hlpr.make_repo_id_string(repo_key)
