@@ -81,7 +81,7 @@ def get_report_id(polly_session, workspace_id: int, workspace_path: str) -> str:
     """
     s3_key = helpers.make_path(workspace_id, workspace_path)
     workspace_endpoint_url = (
-        f"https://v2.api.{polly_session.session.env}.elucidata.io/v3/workspace/_search"
+        f"https://apis.{polly_session.session.env}.elucidata.io/mithoo/_search"
     )
     payload = {
         "from": 0,
